==> haskell-path-pieces-0.2.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path-pieces.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-pieces
version: 0.2.1
id: path-pieces-0.2.1-8v6zSvd6NAW2rVrxx7eIHN
key: path-pieces-0.2.1-8v6zSvd6NAW2rVrxx7eIHN
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: unstable
synopsis: Components of paths.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/path-pieces>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Web.PathPieces
abi: b23651da30dd5feb81eaa3081c1d9ba0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/path-pieces-0.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/path-pieces-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/path-pieces-0.2.1
hs-libraries: HSpath-pieces-0.2.1-8v6zSvd6NAW2rVrxx7eIHN
depends:
    base-4.10.1.0 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj time-1.8.0.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
haddock-interfaces: /usr/share/doc/haskell-path-pieces/html/path-pieces.haddock
haddock-html: /usr/share/doc/haskell-path-pieces/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-pieces-0.2.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path-pieces.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-pieces
version: 0.2.1
id: path-pieces-0.2.1-N9A0XE9UWV4ET35XMVEmE
key: path-pieces-0.2.1-N9A0XE9UWV4ET35XMVEmE
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: unstable
synopsis: Components of paths.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/path-pieces>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Web.PathPieces
abi: 0674eb91f1236faa3e4236a3e0da12e7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/path-pieces-0.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/path-pieces-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/path-pieces-0.2.1
hs-libraries: HSpath-pieces-0.2.1-N9A0XE9UWV4ET35XMVEmE
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj time-1.8.0.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
haddock-interfaces: /usr/share/doc/haskell-path-pieces/html/path-pieces.haddock
haddock-html: /usr/share/doc/haskell-path-pieces/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
